pub enum GenerationError {
IdentityCreationFailed,
}Expand description
Errors that can occur during key generation.
Currently, the only possible failure is if the age library fails to create
a new X25519 identity. This should be extremely rare and typically indicates
a system-level issue (e.g., lack of entropy).
Variants
IdentityCreationFailed
The identity could not be created.
This error is returned when the underlying age crate encounters an
internal failure while generating a new X25519 keypair.