pub struct PublicKey(/* private fields */);Expand description
An age public key, guaranteed to start with “age1”.
Constructed via PublicKey::new, which validates the format.
Can be displayed or converted to a string using expose().
Implementations