Skip to main contentModule config
Source - PROJECT_NAME
- The neuxcfg project name used by this crate.
- get_extra
- Retrieves a single extra field from the project configuration.
- get_neuxcfg
- Returns a new
Neuxcfg instance using the system configuration directory. - init
- Initializes the configuration store for this crate.
- load_config
- Loads the complete project configuration from the persistent store.
- save_config
- Overwrites the entire project configuration.
- set_extra
- Sets a single extra field in the project configuration.
- update_config
- Applies a partial update to the project configuration via deep merge.