Key pair generation.
This module provides build_keypair, the primary function for generating
a fresh X25519 key pair suitable for use with the age encryption tool.
The generation uses cryptographically secure randomness provided by the
operating system.
Functions
- build_
keypair - Generates a new age X25519 key pair.